==========================================================================
collective.dms.scanbehavior
==========================================================================

Features
--------

This behavior adds some metadata related to scanning:
* scan_id : scan identification as a barcode
* version : version number
* pages_number : pages number
* scan_date : scan date
* scan_user : scan user
* scanner : scanner or pc information

Translations
------------

This product has been translated into

- English
- French

Installation
------------

Install collective.dms.scanbehavior by adding it to your buildout::

   [buildout]

    ...

    eggs =
        collective.dms.scanbehavior


and then running "bin/buildout"

Contribute
----------

- Issue Tracker: https://github.com/collective/collective.dms.scanbehavior/issues
- Source Code: https://github.com/collective/collective.dms.scanbehavior

Support
-------

If you are having issues, please let us know.

License
-------

The project is licensed under the GPLv2.
